@@ -40,7 +40,7 @@ class Broker(object):
             v = self.__get()
             if v == "":
                 return {}
-        return json.loads(utf8d(b64d(v)))
+        return jl(b64d_and_utf8d(v))
 
     def get(self, k: str) -> str:
         return self.__decrypt()[k]
@@ -51,7 +51,7 @@ class Broker(object):
         return _
 
     def __encrypt(self, v: dict) -> str:
-        return b64e(utf8e(json.dumps(v)))
+        return b64e(jd(v))
 
     def set(self, k: str, v: str) -> True:
         v = self.__encrypt(self.__set(k, v))
